SyncPointer

Struct SyncPointer 

pub struct SyncPointer<T: ?Sized> { /* private fields */ }
A dynamic threadsafe smart pointer.

A SyncPointer implements Send and Sync, which means the smart pointer it wraps must be Send and Sync (if the data it owns is, that is). For this reason, an Rc cannot be made into a SyncPointer.

Implementations

Source

impl<T> SyncPointer<T>

pub fn new(data: T) -> SyncPointer<T>

Construct a new SyncPointer directly.