pub struct SyncPointer<T: ?Sized> { /* private fields */ }Expand description
A dynamic threadsafe smart pointer.
A SyncPointer implements Send and Sync, which means the smart pointer it wraps must be Send and Sync (if the data it owns is, that is). For this reason, an Rc cannot be made into a SyncPointer.
Implementations
Sourceimpl<T> SyncPointer<T>
impl<T> SyncPointer<T>
Sourcepub fn new(data: T) -> SyncPointer<T>
pub fn new(data: T) -> SyncPointer<T>
Construct a new SyncPointer directly.